pub fn reparent_unit(
mana_dir: &Path,
id: &str,
params: ReparentParams,
) -> Result<ReparentResult>Expand description
Move a unit under a new parent, or detach it to the root.
pub fn reparent_unit(
mana_dir: &Path,
id: &str,
params: ReparentParams,
) -> Result<ReparentResult>Move a unit under a new parent, or detach it to the root.