Module batch_verify

Module batch_verify 

Structs

BatchVerifyFailure
Details of a single unit’s verify failure during batch verification.
BatchVerifyResult
Aggregated result of a batch verify run.

Functions

batch_verify
Run batch verification for all units currently in AwaitingVerify status.
batch_verify_ids
Run batch verification for a specific set of unit IDs.
reopen_awaiting_unit
Set a unit back to Open status and release its claim.