pub fn create(mana_dir: &Path, params: CreateParams) -> Result<CreateResult>Expand description
Create a new unit and persist it to disk.
pub fn create(mana_dir: &Path, params: CreateParams) -> Result<CreateResult>Create a new unit and persist it to disk.