get_diff_hunks

Function get_diff_hunks 

pub fn get_diff_hunks(
    project_root: &Path,
    base_ref: &str,
) -> Result<Vec<DiffHunk>>
Parse git diff output to extract changed lines per file.

Uses --diff-filter=M to only look at modified files (not deleted), and the unified diff format to identify added lines.