pub struct RunScopeWarning {
pub id: String,
pub warning: ScopeWarning,
}Expand description
A non-blocking warning for a unit that will still dispatch.
Fields
id: Stringwarning: ScopeWarningTrait Implementations
Sourceimpl Clone for RunScopeWarning
impl Clone for RunScopeWarning
Sourcefn clone(&self) -> RunScopeWarning
fn clone(&self) -> RunScopeWarning
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RunScopeWarning
impl Debug for RunScopeWarning
Sourceimpl PartialEq for RunScopeWarning
impl PartialEq for RunScopeWarning
Sourcefn eq(&self, other: &RunScopeWarning) -> bool
fn eq(&self, other: &RunScopeWarning) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RunScopeWarning