Module worktree

Module worktree 

Git worktree detection and merge utilities.

This module provides functions to detect if the current directory is within a git worktree, and to merge changes back to the main branch.

Structs

WorktreeInfo
Information about a git worktree.

Enums

MergeResult
Result of a merge operation.

Functions

cleanup_worktree
Clean up a worktree and its branch.
commit_worktree_changes
Commit all changes in the specified worktree directory.
commit_worktree_paths
Commit the specified paths in the worktree directory.
commit_worktree_paths_preserve_index
Commit the specified paths without including or disturbing the real index.
detect_worktree
Detect if the given directory is within a git worktree.
merge_to_main
Merge the worktree branch to main.