GlobalConfig

Struct GlobalConfig 

pub struct GlobalConfig {
Show 25 fields pub auto_close_parent: Option<bool>, pub run: Option<String>, pub plan: Option<String>, pub max_loops: Option<u32>, pub max_concurrent: Option<u32>, pub poll_interval: Option<u32>, pub rules_file: Option<String>, pub file_locking: Option<bool>, pub worktree: Option<bool>, pub on_close: Option<String>, pub on_fail: Option<String>, pub verify_timeout: Option<u64>, pub review: Option<ReviewConfig>, pub user: Option<String>, pub user_email: Option<String>, pub auto_commit: Option<bool>, pub commit_template: Option<String>, pub research: Option<String>, pub run_model: Option<String>, pub plan_model: Option<String>, pub review_model: Option<String>, pub research_model: Option<String>, pub batch_verify: Option<bool>, pub memory_reserve_mb: Option<u64>, pub notify: Option<NotifyConfig>,
}
Global default config stored at ~/.config/mana/config.yaml.

This is a sparse defaults layer: project .mana/config.yaml remains the source of project identity (project, next_id) while global config can provide default operational settings that projects inherit unless they override them locally.

Fields

auto_close_parent: Option<bool>run: Option<String>plan: Option<String>max_loops: Option<u32>max_concurrent: Option<u32>poll_interval: Option<u32>rules_file: Option<String>file_locking: Option<bool>worktree: Option<bool>on_close: Option<String>on_fail: Option<String>verify_timeout: Option<u64>review: Option<ReviewConfig>user: Option<String>user_email: Option<String>auto_commit: Option<bool>commit_template: Option<String>research: Option<String>run_model: Option<String>plan_model: Option<String>review_model: Option<String>research_model: Option<String>batch_verify: Option<bool>memory_reserve_mb: Option<u64>notify: Option<NotifyConfig>

Implementations

Source

impl GlobalConfig

pub fn path() -> Result<PathBuf>

Path to the new global config file: ~/.config/mana/config.yaml.

pub fn load() -> Result<Self>

Load global config. Returns Default if file doesn’t exist.

Falls back to the legacy units config directory if the new path doesn’t exist but the old one does, to support migration from the old location.

pub fn save(&self) -> Result<()>

Save global config to ~/.config/mana/config.yaml, creating parent directories if needed.